@@ -3,13 +3,15 @@ import click
 import os
 from pathlib import Path
 
+from vega import __version__
 from vega.cli.commands.init import init_project
 from vega.cli.commands.generate import generate_component
 from vega.cli.commands.add import add
+from vega.cli.commands.update import update_vega, check_version
 
 
 @click.group()
-@click.version_option(version="0.1.0")
+@click.version_option(version=__version__, prog_name="Vega Framework")
 def cli():
     """
     Vega Framework - Clean Architecture for Python
@@ -53,7 +55,7 @@ def init(project_name, template, path):
 
 @cli.command()
 @click.argument('component_type', type=click.Choice([
-    'entity', 'repository', 'repo', 'service', 'interactor', 'mediator', 'web'
+    'entity', 'repository', 'repo', 'service', 'interactor', 'mediator', 'router'
 ]))
 @click.argument('name')
 @click.option('--path', default='.', help='Project root path')
@@ -69,15 +71,15 @@ def generate(component_type, name, path, impl):
         service     - Service interface (domain layer)
         interactor  - Use case (business logic)
         mediator    - Workflow (orchestrates use cases)
-        web         - Web scaffolding (FastAPI)
+        router      - FastAPI router (requires web module)
 
     Examples:
         vega generate entity Product
         vega generate repository ProductRepository
         vega generate repository Product --impl memory
-        vega generate web fastapi
         vega generate interactor CreateProduct
         vega generate mediator CheckoutFlow
+        vega generate router Product
     """
     # Normalize 'repo' to 'repository'
     if component_type == 'repo':
@@ -106,6 +108,24 @@ def doctor(path):
     click.echo("⚠️  Feature not implemented yet. Coming soon!")
 
 
+@cli.command()
+@click.option('--check', is_flag=True, help='Check for updates without installing')
+@click.option('--force', is_flag=True, help='Force reinstall even if up to date')
+def update(check, force):
+    """
+    Update Vega Framework to the latest version.
+
+    Examples:
+        vega update              # Update to latest version
+        vega update --check      # Check for updates only
+        vega update --force      # Force reinstall
+    """
+    if check:
+        check_version()
+    else:
+        update_vega(force=force)
+
+
 # Register the add command
 cli.add_command(add)
 
